Package: simulist
Title: Simulate Disease Outbreak Line List and Contacts Data
Version: 0.7.0
Authors@R: c(
    person("Joshua W.", "Lambert", , "joshua.lambert@lshtm.ac.uk", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-5218-3046")),
    person("Carmen", "Tamayo Cuartero", , "carmen.tamayo-cuartero@lshtm.ac.uk", role = "aut",
           comment = c(ORCID = "0000-0003-4184-2864")),
    person("Hugo", "Gruson", , "hugo@data.org", role = c("ctb", "rev"),
           comment = c(ORCID = "0000-0002-4094-1476")),
    person("Pratik R.", "Gupte", , "pratik.gupte@lshtm.ac.uk", role = c("ctb", "rev"),
           comment = c(ORCID = "0000-0001-5294-7819")),
    person("Adam", "Kucharski", , "adam.kucharski@lshtm.ac.uk", role = "rev",
           comment = c(ORCID = "0000-0001-8814-9421")),
    person("Chris", "Hartgerink", , "chris@data.org", role = "rev",
           comment = c(ORCID = "0000-0003-1050-6809")),
    person("Sebastian", "Funk", , "sebastian.funk@lshtm.ac.uk", role = "ctb",
           comment = c(ORCID = "0000-0002-2842-3406")),
    person("London School of Hygiene and Tropical Medicine, LSHTM", role = "cph",
           comment = c(ROR = "00a0jsq62"))
  )
Description: Tools to simulate realistic raw case data for an epidemic in
    the form of line lists and contacts using a branching process.
    Simulated outbreaks are parameterised with epidemiological parameters
    and can have age-structured populations, age-stratified
    hospitalisation and death risk and time-varying case fatality risk.
License: MIT + file LICENSE
URL: https://github.com/epiverse-trace/simulist,
        https://epiverse-trace.github.io/simulist/
BugReports: https://github.com/epiverse-trace/simulist/issues
Depends: R (>= 4.2.0)
Imports: checkmate, english, epiparameter (>= 0.4.0), grates,
        randomNames, rlang, stats
Suggests: dplyr, epicontacts (>= 1.1.3), ggplot2, incidence2 (>=
        2.6.2), knitr, rmarkdown, spelling, testthat (>= 3.0.0), tidyr
VignetteBuilder: knitr
Config/Needs/website: epiverse-trace/epiversetheme
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-GB
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-02-06 10:11:09 UTC; lshjl15
Author: Joshua W. Lambert [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-5218-3046>),
  Carmen Tamayo Cuartero [aut] (ORCID:
    <https://orcid.org/0000-0003-4184-2864>),
  Hugo Gruson [ctb, rev] (ORCID: <https://orcid.org/0000-0002-4094-1476>),
  Pratik R. Gupte [ctb, rev] (ORCID:
    <https://orcid.org/0000-0001-5294-7819>),
  Adam Kucharski [rev] (ORCID: <https://orcid.org/0000-0001-8814-9421>),
  Chris Hartgerink [rev] (ORCID: <https://orcid.org/0000-0003-1050-6809>),
  Sebastian Funk [ctb] (ORCID: <https://orcid.org/0000-0002-2842-3406>),
  London School of Hygiene and Tropical Medicine, LSHTM [cph] (ROR:
    <https://ror.org/00a0jsq62>)
Maintainer: Joshua W. Lambert <joshua.lambert@lshtm.ac.uk>
Repository: CRAN
Date/Publication: 2026-02-06 11:20:02 UTC
Built: R 4.6.0; ; 2026-04-28 11:12:31 UTC; unix
